@@ -3,8 +3,8 @@ package highlight
 import (
 	"testing"
 
-	"github.com/elves/elvish/pkg/parse"
-	"github.com/elves/elvish/pkg/tt"
+	"src.elv.sh/pkg/parse"
+	"src.elv.sh/pkg/tt"
 )
 
 var Args = tt.Args
@@ -52,15 +52,7 @@ func TestGetRegions(t *testing.T) {
 			{2, 12, lexicalRegion, commentRegion}, // # comment
 		}),
 
-		// LHS of assignments.
-
-		Args("x y = foo bar").Rets([]region{
-			{0, 1, semanticRegion, variableRegion},  // x
-			{2, 3, semanticRegion, variableRegion},  // y
-			{4, 5, lexicalRegion, barewordRegion},   // =
-			{6, 9, lexicalRegion, barewordRegion},   // foo
-			{10, 13, lexicalRegion, barewordRegion}, // bar
-		}),
+		// LHS of temporary assignments.
 		Args("x=foo ls").Rets([]region{
 			{0, 1, semanticRegion, variableRegion}, // x
 			{1, 2, lexicalRegion, "="},
@@ -84,6 +76,14 @@ func TestGetRegions(t *testing.T) {
 			{8, 11, lexicalRegion, barewordRegion}, // foo
 		}),
 
+		// The "tmp" special command
+		Args("tmp x = foo").Rets([]region{
+			{0, 3, semanticRegion, commandRegion},  // tmp
+			{4, 5, semanticRegion, variableRegion}, // x
+			{6, 7, semanticRegion, keywordRegion},  // =
+			{8, 11, lexicalRegion, barewordRegion}, // foo
+		}),
+
 		// The "if" special command.
 
 		Args("if x { }").Rets([]region{
@@ -159,6 +159,16 @@ func TestGetRegions(t *testing.T) {
 			{28, 29, lexicalRegion, "}"},
 		}),
 
+		// Regression test for b.elv.sh/1358.
+		Args("try { } except { }").Rets([]region{
+			{0, 3, semanticRegion, commandRegion}, // try
+			{4, 5, lexicalRegion, "{"},
+			{6, 7, lexicalRegion, "}"},
+			{8, 14, semanticRegion, keywordRegion}, // except
+			{15, 16, lexicalRegion, "{"},
+			{17, 18, lexicalRegion, "}"},
+		}),
+
 		Args("try { } finally { }").Rets([]region{
 			{0, 3, semanticRegion, commandRegion}, // try
 			{4, 5, lexicalRegion, "{"},
@@ -172,6 +182,6 @@ func TestGetRegions(t *testing.T) {
 
 func getRegionsFromString(code string) []region {
 	// Ignore error.
-	tree, _ := parse.Parse(parse.SourceForTest(code))
+	tree, _ := parse.Parse(parse.SourceForTest(code), parse.Config{})
 	return getRegions(tree.Root)
 }
