@@ -5,8 +5,11 @@ import (
 	"testing"
 	"time"
 
+	"src.elv.sh/pkg/diag"
 	. "src.elv.sh/pkg/eval"
+	"src.elv.sh/pkg/parse"
 
+	"src.elv.sh/pkg/eval/errs"
 	. "src.elv.sh/pkg/eval/evaltest"
 	"src.elv.sh/pkg/eval/vals"
 	"src.elv.sh/pkg/testutil"
@@ -21,36 +24,45 @@ func TestKindOf(t *testing.T) {
 
 func TestConstantly(t *testing.T) {
 	Test(t,
-		That(`f = (constantly foo); $f; $f`).Puts("foo", "foo"),
+		That(`var f = (constantly foo); $f; $f`).Puts("foo", "foo"),
 		thatOutputErrorIsBubbled("(constantly foo)"),
 	)
 }
 
+func TestCallCommand(t *testing.T) {
+	Test(t,
+		That(`call {|arg &opt=v| put $arg $opt } [foo] [&opt=bar]`).
+			Puts("foo", "bar"),
+		That(`call { } [foo] [&[]=bar]`).
+			Throws(errs.BadValue{What: "option key", Valid: "string", Actual: "list"}),
+	)
+}
+
 func TestEval(t *testing.T) {
 	Test(t,
 		That("eval 'put x'").Puts("x"),
 		// Using variable from the local scope.
-		That("x = foo; eval 'put $x'").Puts("foo"),
+		That("var x = foo; eval 'put $x'").Puts("foo"),
 		// Setting a variable in the local scope.
-		That("x = foo; eval 'x = bar'; put $x").Puts("bar"),
+		That("var x = foo; eval 'set x = bar'; put $x").Puts("bar"),
 		// Using variable from the upvalue scope.
-		That("x = foo; { nop $x; eval 'put $x' }").Puts("foo"),
+		That("var x = foo; { nop $x; eval 'put $x' }").Puts("foo"),
 		// Specifying a namespace.
-		That("n = (ns [&x=foo]); eval 'put $x' &ns=$n").Puts("foo"),
+		That("var n = (ns [&x=foo]); eval 'put $x' &ns=$n").Puts("foo"),
 		// Altering variables in the specified namespace.
-		That("n = (ns [&x=foo]); eval 'x = bar' &ns=$n; put $n[x]").Puts("bar"),
+		That("var n = (ns [&x=foo]); eval 'set x = bar' &ns=$n; put $n[x]").Puts("bar"),
 		// Newly created variables do not appear in the local namespace.
 		That("eval 'x = foo'; put $x").DoesNotCompile(),
 		// Newly created variables do not alter the specified namespace, either.
-		That("n = (ns [&]); eval &ns=$n 'x = foo'; put $n[x]").
+		That("var n = (ns [&]); eval &ns=$n 'var x = foo'; put $n[x]").
 			Throws(vals.NoSuchKey("x"), "$n[x]"),
 		// However, newly created variable can be accessed in the final
 		// namespace using &on-end.
-		That("eval &on-end={|n| put $n[x] } 'x = foo'").Puts("foo"),
+		That("eval &on-end={|n| put $n[x] } 'var x = foo'").Puts("foo"),
 		// Parse error.
-		That("eval '['").Throws(AnyError),
+		That("eval '['").Throws(ErrorWithType(&parse.Error{})),
 		// Compilation error.
-		That("eval 'put $x'").Throws(AnyError),
+		That("eval 'put $x'").Throws(ErrorWithType(&diag.Error{})),
 		// Exception.
 		That("eval 'fail x'").Throws(FailError{"x"}),
 	)
@@ -72,9 +84,9 @@ func TestTime(t *testing.T) {
 	Test(t,
 		// Since runtime duration is non-deterministic, we only have some sanity
 		// checks here.
-		That("time { echo foo } | a _ = (all)", "put $a").Puts("foo"),
-		That("duration = ''",
-			"time &on-end={|x| duration = $x } { echo foo } | out = (all)",
+		That("time { echo foo } | var a _ = (all)", "put $a").Puts("foo"),
+		That("var duration = ''",
+			"time &on-end={|x| set duration = $x } { echo foo } | var out = (all)",
 			"put $out", "kind-of $duration").Puts("foo", "number"),
 		That("time { fail body } | nop (all)").Throws(FailError{"body"}),
 		That("time &on-end={|_| fail on-end } { }").Throws(
@@ -89,7 +101,7 @@ func TestTime(t *testing.T) {
 
 func TestUseMod(t *testing.T) {
 	testutil.InTempDir(t)
-	testutil.MustWriteFile("mod.elv", "x = value")
+	testutil.MustWriteFile("mod.elv", "var x = value")
 
 	Test(t,
 		That("put (use-mod ./mod)[x]").Puts("value"),
