@@ -47,6 +47,7 @@ func init() {
 	builtinSpecials = map[string]compileBuiltin{
 		"var": compileVar,
 		"set": compileSet,
+		"tmp": compileTmp,
 		"del": compileDel,
 		"fn":  compileFn,
 
@@ -70,61 +71,52 @@ func init() {
 
 // VarForm = 'var' { VariablePrimary } [ '=' { Compound } ]
 func compileVar(cp *compiler, fn *parse.Form) effectOp {
-	eqIndex := -1
-	for i, cn := range fn.Args {
-		if parse.SourceText(cn) == "=" {
-			eqIndex = i
-			break
-		}
-	}
-
-	if eqIndex == -1 {
-		cp.parseCompoundLValues(fn.Args, newLValue)
+	lhsArgs, rhs := compileLHSRHS(cp, fn)
+	lhs := cp.parseCompoundLValues(lhsArgs, newLValue)
+	if rhs == nil {
 		// Just create new variables, nothing extra to do at runtime.
 		return nopOp{}
 	}
-	// Compile rhs before lhs before many potential shadowing
-	var rhs valuesOp
-	if eqIndex == len(fn.Args)-1 {
-		rhs = nopValuesOp{diag.PointRanging(fn.Range().To)}
-	} else {
-		rhs = seqValuesOp{
-			diag.MixedRanging(fn.Args[eqIndex+1], fn.Args[len(fn.Args)-1]),
-			cp.compoundOps(fn.Args[eqIndex+1:])}
-	}
-	lhs := cp.parseCompoundLValues(fn.Args[:eqIndex], newLValue)
-	return &assignOp{fn.Range(), lhs, rhs}
-}
-
-// IsUnqualified returns whether name is an unqualified variable name.
-func IsUnqualified(name string) bool {
-	i := strings.IndexByte(name, ':')
-	return i == -1 || i == len(name)-1
+	return &assignOp{fn.Range(), lhs, rhs, false}
 }
 
 // SetForm = 'set' { LHS } '=' { Compound }
 func compileSet(cp *compiler, fn *parse.Form) effectOp {
-	eq := -1
-	for i, cn := range fn.Args {
-		if parse.SourceText(cn) == "=" {
-			eq = i
-			break
-		}
+	lhs, rhs := compileSetArgs(cp, fn)
+	return &assignOp{fn.Range(), lhs, rhs, false}
+}
+
+// TmpForm = 'tmp' { LHS } '=' { Compound }
+func compileTmp(cp *compiler, fn *parse.Form) effectOp {
+	if len(cp.scopes) <= 1 {
+		cp.errorpf(fn, "tmp may only be used inside a function")
 	}
-	if eq == -1 {
+	lhs, rhs := compileSetArgs(cp, fn)
+	return &assignOp{fn.Range(), lhs, rhs, true}
+}
+
+func compileSetArgs(cp *compiler, fn *parse.Form) (lvaluesGroup, valuesOp) {
+	lhsArgs, rhs := compileLHSRHS(cp, fn)
+	if rhs == nil {
 		cp.errorpf(diag.PointRanging(fn.Range().To), "need = and right-hand-side")
 	}
-	lhs := cp.parseCompoundLValues(fn.Args[:eq], setLValue)
-	var rhs valuesOp
-	if eq == len(fn.Args)-1 {
-		rhs = nopValuesOp{diag.PointRanging(fn.Range().To)}
-	} else {
-		rhs = seqValuesOp{
-			diag.MixedRanging(fn.Args[eq+1], fn.Args[len(fn.Args)-1]),
-			cp.compoundOps(fn.Args[eq+1:])}
-	}
-	return &assignOp{fn.Range(), lhs, rhs}
+	lhs := cp.parseCompoundLValues(lhsArgs, setLValue)
+	return lhs, rhs
+}
 
+func compileLHSRHS(cp *compiler, fn *parse.Form) ([]*parse.Compound, valuesOp) {
+	for i, cn := range fn.Args {
+		if parse.SourceText(cn) == "=" {
+			lhs := fn.Args[:i]
+			if i == len(fn.Args)-1 {
+				return lhs, nopValuesOp{diag.PointRanging(fn.Range().To)}
+			}
+			return lhs, seqValuesOp{
+				diag.MixedRanging(fn.Args[i+1], fn.Args[len(fn.Args)-1]),
+				cp.compoundOps(fn.Args[i+1:])}
+		}
+	}
+	return fn.Args, nil
 }
 
 const delArgMsg = "arguments to del must be variable or variable elements"
@@ -158,7 +150,7 @@ func compileDel(cp *compiler, fn *parse.Form) effectOp {
 				f = delLocalVarOp{ref.index}
 				cp.thisScope().infos[ref.index].deleted = true
 			} else {
-				cp.errorpf(cn, "only variables in local: or E: can be deleted")
+				cp.errorpf(cn, "only variables in the local scope or E: can be deleted")
 				continue
 			}
 		} else {
@@ -260,8 +252,8 @@ func (op fnOp) exec(fm *Frame) Exception {
 	if exc != nil {
 		return exc
 	}
-	c := values[0].(*closure)
-	c.Op = fnWrap{c.Op}
+	c := values[0].(*Closure)
+	c.op = fnWrap{c.op}
 	return fm.errorp(op.keywordRange, fm.local.slots[op.varIndex].Set(c))
 }
 
@@ -495,13 +487,13 @@ func compileIf(cp *compiler, fn *parse.Form) effectOp {
 	condLeader := "if"
 	for {
 		condNodes = append(condNodes, args.next())
-		bodyNodes = append(bodyNodes, args.nextMustLambda(condLeader))
+		bodyNodes = append(bodyNodes, args.nextMustThunk(condLeader))
 		if !args.nextIs("elif") {
 			break
 		}
 		condLeader = "elif"
 	}
-	elseNode := args.nextMustLambdaIfAfter("else")
+	elseNode := args.nextMustThunkIfAfter("else")
 	args.mustEnd()
 
 	condOps := cp.compoundOps(condNodes)
@@ -528,16 +520,16 @@ func (op *ifOp) exec(fm *Frame) Exception {
 	}
 	elseFn := execLambdaOp(fm, op.elseOp)
 	for i, condOp := range op.condOps {
-		condValues, exc := condOp.exec(fm.fork("if cond"))
+		condValues, exc := condOp.exec(fm.Fork("if cond"))
 		if exc != nil {
 			return exc
 		}
 		if allTrue(condValues) {
-			return fm.errorp(op, bodies[i].Call(fm.fork("if body"), NoArgs, NoOpts))
+			return fm.errorp(op, bodies[i].Call(fm.Fork("if body"), NoArgs, NoOpts))
 		}
 	}
 	if op.elseOp != nil {
-		return fm.errorp(op, elseFn.Call(fm.fork("if else"), NoArgs, NoOpts))
+		return fm.errorp(op, elseFn.Call(fm.Fork("if else"), NoArgs, NoOpts))
 	}
 	return nil
 }
@@ -545,8 +537,8 @@ func (op *ifOp) exec(fm *Frame) Exception {
 func compileWhile(cp *compiler, fn *parse.Form) effectOp {
 	args := cp.walkArgs(fn)
 	condNode := args.next()
-	bodyNode := args.nextMustLambda("while body")
-	elseNode := args.nextMustLambdaIfAfter("else")
+	bodyNode := args.nextMustThunk("while body")
+	elseNode := args.nextMustThunkIfAfter("else")
 	args.mustEnd()
 
 	condOp := cp.compoundOp(condNode)
@@ -570,7 +562,7 @@ func (op *whileOp) exec(fm *Frame) Exception {
 
 	iterated := false
 	for {
-		condValues, exc := op.condOp.exec(fm.fork("while cond"))
+		condValues, exc := op.condOp.exec(fm.Fork("while cond"))
 		if exc != nil {
 			return exc
 		}
@@ -578,7 +570,7 @@ func (op *whileOp) exec(fm *Frame) Exception {
 			break
 		}
 		iterated = true
-		err := body.Call(fm.fork("while"), NoArgs, NoOpts)
+		err := body.Call(fm.Fork("while"), NoArgs, NoOpts)
 		if err != nil {
 			exc := err.(Exception)
 			if exc.Reason() == Continue {
@@ -592,7 +584,7 @@ func (op *whileOp) exec(fm *Frame) Exception {
 	}
 
 	if op.elseOp != nil && !iterated {
-		return fm.errorp(op, elseBody.Call(fm.fork("while else"), NoArgs, NoOpts))
+		return fm.errorp(op, elseBody.Call(fm.Fork("while else"), NoArgs, NoOpts))
 	}
 	return nil
 }
@@ -601,8 +593,8 @@ func compileFor(cp *compiler, fn *parse.Form) effectOp {
 	args := cp.walkArgs(fn)
 	varNode := args.next()
 	iterNode := args.next()
-	bodyNode := args.nextMustLambda("for body")
-	elseNode := args.nextMustLambdaIfAfter("else")
+	bodyNode := args.nextMustThunk("for body")
+	elseNode := args.nextMustThunkIfAfter("else")
 	args.mustEnd()
 
 	lvalue := cp.compileOneLValue(varNode, setLValue|newLValue)
@@ -647,7 +639,7 @@ func (op *forOp) exec(fm *Frame) Exception {
 			errElement = err
 			return false
 		}
-		err = body.Call(fm.fork("for"), NoArgs, NoOpts)
+		err = body.Call(fm.Fork("for"), NoArgs, NoOpts)
 		if err != nil {
 			exc := err.(Exception)
 			if exc.Reason() == Continue {
@@ -669,7 +661,7 @@ func (op *forOp) exec(fm *Frame) Exception {
 	}
 
 	if !iterated && elseBody != nil {
-		return fm.errorp(op, elseBody.Call(fm.fork("for else"), NoArgs, NoOpts))
+		return fm.errorp(op, elseBody.Call(fm.Fork("for else"), NoArgs, NoOpts))
 	}
 	return nil
 }
@@ -677,32 +669,39 @@ func (op *forOp) exec(fm *Frame) Exception {
 func compileTry(cp *compiler, fn *parse.Form) effectOp {
 	logger.Println("compiling try")
 	args := cp.walkArgs(fn)
-	bodyNode := args.nextMustLambda("try body")
+	bodyNode := args.nextMustThunk("try body")
 	logger.Printf("body is %q", parse.SourceText(bodyNode))
-	var exceptVarNode *parse.Compound
-	var exceptNode *parse.Primary
-	if args.nextIs("except") {
-		logger.Println("except-ing")
+	var catchVarNode *parse.Compound
+	var catchNode *parse.Primary
+	if args.peekIs("except") {
+		cp.deprecate(args.peek(),
+			`"except" is deprecated; use "catch" instead`, 18)
+	}
+	if args.nextIs("except") || args.nextIs("catch") {
 		// Parse an optional lvalue into exceptVarNode.
 		n := args.peek()
 		if _, ok := cmpd.StringLiteral(n); ok {
-			exceptVarNode = n
+			catchVarNode = n
 			args.next()
 		}
-		exceptNode = args.nextMustLambda("except body")
+		catchNode = args.nextMustThunk("catch body")
 	}
-	elseNode := args.nextMustLambdaIfAfter("else")
-	finallyNode := args.nextMustLambdaIfAfter("finally")
+	elseNode := args.nextMustThunkIfAfter("else")
+	finallyNode := args.nextMustThunkIfAfter("finally")
 	args.mustEnd()
 
-	var exceptVar lvalue
-	var bodyOp, exceptOp, elseOp, finallyOp valuesOp
-	bodyOp = cp.primaryOp(bodyNode)
-	if exceptVarNode != nil {
-		exceptVar = cp.compileOneLValue(exceptVarNode, setLValue|newLValue)
+	if catchNode == nil && finallyNode == nil {
+		cp.errorpf(fn, "try must be followed by a catch block or a finally block")
 	}
-	if exceptNode != nil {
-		exceptOp = cp.primaryOp(exceptNode)
+
+	var catchVar lvalue
+	var bodyOp, catchOp, elseOp, finallyOp valuesOp
+	bodyOp = cp.primaryOp(bodyNode)
+	if catchVarNode != nil {
+		catchVar = cp.compileOneLValue(catchVarNode, setLValue|newLValue)
+	}
+	if catchNode != nil {
+		catchOp = cp.primaryOp(catchNode)
 	}
 	if elseNode != nil {
 		elseOp = cp.primaryOp(elseNode)
@@ -711,14 +710,14 @@ func compileTry(cp *compiler, fn *parse.Form) effectOp {
 		finallyOp = cp.primaryOp(finallyNode)
 	}
 
-	return &tryOp{fn.Range(), bodyOp, exceptVar, exceptOp, elseOp, finallyOp}
+	return &tryOp{fn.Range(), bodyOp, catchVar, catchOp, elseOp, finallyOp}
 }
 
 type tryOp struct {
 	diag.Ranging
 	bodyOp    valuesOp
-	exceptVar lvalue
-	exceptOp  valuesOp
+	catchVar  lvalue
+	catchOp   valuesOp
 	elseOp    valuesOp
 	finallyOp valuesOp
 }
@@ -726,35 +725,35 @@ type tryOp struct {
 func (op *tryOp) exec(fm *Frame) Exception {
 	body := execLambdaOp(fm, op.bodyOp)
 	var exceptVar vars.Var
-	if op.exceptVar.ref != nil {
+	if op.catchVar.ref != nil {
 		var err error
-		exceptVar, err = derefLValue(fm, op.exceptVar)
+		exceptVar, err = derefLValue(fm, op.catchVar)
 		if err != nil {
 			return fm.errorp(op, err)
 		}
 	}
-	except := execLambdaOp(fm, op.exceptOp)
+	catch := execLambdaOp(fm, op.catchOp)
 	elseFn := execLambdaOp(fm, op.elseOp)
 	finally := execLambdaOp(fm, op.finallyOp)
 
-	err := body.Call(fm.fork("try body"), NoArgs, NoOpts)
+	err := body.Call(fm.Fork("try body"), NoArgs, NoOpts)
 	if err != nil {
-		if except != nil {
+		if catch != nil {
 			if exceptVar != nil {
 				err := exceptVar.Set(err.(Exception))
 				if err != nil {
-					return fm.errorp(op.exceptVar, err)
+					return fm.errorp(op.catchVar, err)
 				}
 			}
-			err = except.Call(fm.fork("try except"), NoArgs, NoOpts)
+			err = catch.Call(fm.Fork("try catch"), NoArgs, NoOpts)
 		}
 	} else {
 		if elseFn != nil {
-			err = elseFn.Call(fm.fork("try else"), NoArgs, NoOpts)
+			err = elseFn.Call(fm.Fork("try else"), NoArgs, NoOpts)
 		}
 	}
 	if finally != nil {
-		errFinally := finally.Call(fm.fork("try finally"), NoArgs, NoOpts)
+		errFinally := finally.Call(fm.Fork("try finally"), NoArgs, NoOpts)
 		if errFinally != nil {
 			// TODO: If err is not nil, this discards err. Use something similar
 			// to pipeline exception to expose both.
