@@ -17,6 +17,23 @@ var (
 	ErrNoOptAccepted = errors.New("function does not accept any options")
 )
 
+// WrongArgType is thrown when calling a native function with an argument of the
+// wrong type.
+type WrongArgType struct {
+	argNum    int
+	typeError error
+}
+
+// Error implements the error interface.
+func (e WrongArgType) Error() string {
+	return fmt.Sprintf("wrong type for arg #%d: %v", e.argNum, e.typeError)
+}
+
+// Unwrap returns the wrapped type error.
+func (e WrongArgType) Unwrap() error {
+	return e.typeError
+}
+
 type goFn struct {
 	name string
 	impl interface{}
@@ -201,7 +218,7 @@ func (b *goFn) Call(f *Frame, args []interface{}, opts map[string]interface{}) e
 		ptr := reflect.New(typ)
 		err := vals.ScanToGo(arg, ptr.Interface())
 		if err != nil {
-			return fmt.Errorf("wrong type of argument %d: %v", i, err)
+			return WrongArgType{i, err}
 		}
 		in = append(in, ptr.Elem())
 	}
