@@ -2,7 +2,6 @@ package main
 
 import (
 	"io"
-	"io/ioutil"
 	"os"
 	"path"
 	"strings"
@@ -21,7 +20,7 @@ var extractTests = []struct {
 	{name: "Source without elvdoc", src: "package x\n// not elvdoc", wantDoc: ""},
 
 	{
-		name: "Source with doc-fn",
+		name: "Source with elvdoc:fn",
 		src: `package x
 
 //elvdoc:fn cd
@@ -32,12 +31,30 @@ var extractTests = []struct {
 
 <a name='//apple_ref/cpp/Function/cd' class='dashAnchor'></a>
 
-## cd
+## cd {#cd}
 
 Changes directory.
 `,
 	},
 
+	{
+		name: "symbol with punctuation and specified ID",
+		src: `package x
+
+//elvdoc:fn + {#add}
+//
+// Add.
+`,
+		wantDoc: `# Functions
+
+<a name='//apple_ref/cpp/Function/%2B' class='dashAnchor'></a>
+
+## + {#add}
+
+Add.
+`,
+	},
+
 	{
 		name: "Source with unstable symbols",
 		src: `package x
@@ -54,19 +71,19 @@ Changes directory.
 		ns: "ns:",
 		wantDoc: `# Functions
 
-<a name='//apple_ref/cpp/Function/ns:a' class='dashAnchor'></a>
+<a name='//apple_ref/cpp/Function/ns%3Aa' class='dashAnchor'></a>
 
-## ns:a
+## ns:a {#ns:a}
 A.
 
-<a name='//apple_ref/cpp/Function/ns:b' class='dashAnchor'></a>
+<a name='//apple_ref/cpp/Function/ns%3Ab' class='dashAnchor'></a>
 
-## ns:b
+## ns:b {#ns:b}
 B.
 
-<a name='//apple_ref/cpp/Function/ns:-b' class='dashAnchor'></a>
+<a name='//apple_ref/cpp/Function/ns%3A-b' class='dashAnchor'></a>
 
-## ns:-b
+## ns:-b {#ns:-b}
 -B.
 `,
 	},
@@ -87,17 +104,17 @@ B.
 
 <a name='//apple_ref/cpp/Function/a' class='dashAnchor'></a>
 
-## a
+## a {#a}
 A.
 
 <a name='//apple_ref/cpp/Function/b' class='dashAnchor'></a>
 
-## b
+## b {#b}
 B.
 
 <a name='//apple_ref/cpp/Function/c' class='dashAnchor'></a>
 
-## c
+## c {#c}
 C.
 `,
 	},
@@ -114,9 +131,9 @@ C.
 `,
 		wantDoc: `# Variables
 
-<a name='//apple_ref/cpp/Variable/$b' class='dashAnchor'></a>
+<a name='//apple_ref/cpp/Variable/%24b' class='dashAnchor'></a>
 
-## $b
+## $b {#b}
 B.
 
 
@@ -124,7 +141,33 @@ B.
 
 <a name='//apple_ref/cpp/Function/a' class='dashAnchor'></a>
 
-## a
+## a {#a}
+A.
+`,
+	},
+
+	{
+		name: "Elvish source",
+		src: `
+#elvdoc:fn a
+# A.
+
+#elvdoc:var b
+# B.
+`,
+		wantDoc: `# Variables
+
+<a name='//apple_ref/cpp/Variable/%24b' class='dashAnchor'></a>
+
+## $b {#b}
+B.
+
+
+# Functions
+
+<a name='//apple_ref/cpp/Function/a' class='dashAnchor'></a>
+
+## a {#a}
 A.
 `,
 	},
@@ -139,7 +182,7 @@ A.
 
 <a name='//apple_ref/cpp/Function/a' class='dashAnchor'></a>
 
-## a
+## a {#a}
 A.
 `,
 	},
@@ -156,17 +199,17 @@ A.
 		ns: "ns:",
 		wantDoc: `# Variables
 
-<a name='//apple_ref/cpp/Variable/$ns:b' class='dashAnchor'></a>
+<a name='//apple_ref/cpp/Variable/%24ns%3Ab' class='dashAnchor'></a>
 
-## $ns:b
+## $ns:b {#ns:b}
 B.
 
 
 # Functions
 
-<a name='//apple_ref/cpp/Function/ns:a' class='dashAnchor'></a>
+<a name='//apple_ref/cpp/Function/ns%3Aa' class='dashAnchor'></a>
 
-## ns:a
+## ns:a {#ns:a}
 A.
 `,
 	}}
@@ -191,9 +234,9 @@ func TestRun_MultipleFiles(t *testing.T) {
 	run([]string{"a.go", "b.go"}, emptyReader, w)
 	compare(t, w.String(), `# Variables
 
-<a name='//apple_ref/cpp/Variable/$v2' class='dashAnchor'></a>
+<a name='//apple_ref/cpp/Variable/%24v2' class='dashAnchor'></a>
 
-## $v2
+## $v2 {#v2}
 
 Variable 2 from b.
 
@@ -202,13 +245,13 @@ Variable 2 from b.
 
 <a name='//apple_ref/cpp/Function/f1' class='dashAnchor'></a>
 
-## f1
+## f1 {#f1}
 
 Function 1 from b.
 
 <a name='//apple_ref/cpp/Function/f2' class='dashAnchor'></a>
 
-## f2
+## f2 {#f2}
 
 Function 2 from a.
 
@@ -271,5 +314,5 @@ func writeFile(name, data string) {
 	if err != nil {
 		panic(err)
 	}
-	ioutil.WriteFile(name, []byte(data), 0600)
+	os.WriteFile(name, []byte(data), 0600)
 }
